================================
 2014-07-11 Election Activities
================================

We expect all members of our community to adhere to the highest
standards of behavior during Technical Committee and Program Technical
Leader elections. Everyone should respect the election process, as set
out in the `Community Code of Conduct`_, and all campaign activities
should be conducted in the spirit of the OpenStack ideals of
"Openness, Transparency, Commonality, Integration, Quality..." listed
in the `TC Mission Statement`_.

We trust the instincts, good faith, maturity, and sound judgement of
our community members. Talking about governance issues in person at
official OpenStack events or privately with co-workers or friends is
expected. However, we are a diverse, world-wide community, and we
encourage everyone to discuss community issues publicly using
inclusive forums where we can all learn from and contribute to the
conversation. Using the `development mailing list`_ for those
discussions ensures that everyone has an opportunity to participate,
unlike exclusionary forums such as private mailings and in-person
events that overlook community members who cannot travel to the event,
even if no invitation is required to gain entrance.

Administering Elections
=======================

Prior to each election, the TC names community members to administer
the election. As described in the `Technical Committee Charter`_,
these election officials identify the appropriate electorate, verify
all candidates' qualifications, configure the voting software, and
ensure that votes are collected and counted properly.

Although we hope that everyone will follow our community ideals, we
recognize that, whether through mistakes or bad intent, that will not
always be the case.  In addition to the logistical operation of the
election, the election officials are also responsible for receiving
reports of potential abuse.

During the election, the officials report to the active members of the
TC (defined as those members whose terms have not expired and have not
stepped down for other reasons). Of course, any active TC member
involved in the election (such as for a PTL position) would not be
involved in resolving any issues.  This ensures that TC members
running in the election do not have undue influence over its outcome,
while also maintaining oversight by the elected representatives still
serving on the TC.

Reporting Problems
==================

If you observe a problem with the election or campaigning activities,
you should bring the details to the election officials privately for
an impartial review.

The officials will report privately to the active TC members, who will
work with the election officials to talk to all of the parties
affected and determine how to resolve the situation. The resolution
may include private apologies and reprimands, or, in extreme cases,
voiding and re-running the election.

After the matter is resolved, the active TC members and election
officials will prepare and publish an official summary of the
incident. In most cases, the names of people and companies involved
will be redacted because the goal of the incident report is to
emphasize our community culture and values through education, rather
than to publicly punish the parties involved.

In an especially extreme case, the active TC members may decide to
refer the issue to the OpenStack Foundation Executive Director and
Secretary for further action related to the Code of Conduct or other
Foundation rules. Community members always retain the right to report
issues to the Foundation staff directly, following the processes
described in the Code of Conduct.

.. _Technical Committee Charter: https://wiki.openstack.org/wiki/Governance/Foundation/TechnicalCommittee#OpenStack_Technical_Committee_charter
.. _Community Code of Conduct: http://www.openstack.org/legal/community-code-of-conduct
.. _TC Mission Statement: https://wiki.openstack.org/wiki/Governance/Foundation/TechnicalCommittee
.. _development mailing list: http://lists.openstack.org/cgi-bin/mailman/listinfo/openstack-dev
